# pixiv-bulk-downloader

[![Maintainability](https://api.codeclimate.com/v1/badges/f4083498009bd92d2d05/maintainability)](https://codeclimate.com/github/eggplants/pixiv-bulk-downloader/maintainability) [![Release Package](https://github.com/eggplants/pixiv-bulk-downloader/workflows/Release%20Package/badge.svg)](https://github.com/eggplants/pixiv-bulk-downloader/actions/runs/345374681/workflow) [![PyPI version](https://badge.fury.io/py/pixiv-bulk-downloader.svg)](https://badge.fury.io/py/pixiv-bulk-downloader)

- Pixiv Bulk Downloader

## Feature

- Download
  - works of following users
    - SAVE: `$HOME/pbd/following`
  - bookmarked works
    - SAVE: `$HOME/pbd/bookmarks`

## Try

Note: _In advance, please setup google-chrome-stable + selenium + webdriver_

```bash
# pip 3.x
pip install pixiv-bulk-downloader
# run
pbd
[+]ID is mail address, userid, account name.
[+]ID:
[+]Password:
get_all_following_works? [yn]:
get_all_bookmarked_works? [yn]:
```
